@@ -65,11 +65,11 @@ Web::MREST::CLI::UserAgent - HTTP user agent for command-line client
 
 =head1 VERSION
 
-Version 0.256
+Version 0.261
 
 =cut
 
-our $VERSION = '0.256';
+our $VERSION = '0.261';
 
 
 
@@ -163,7 +163,7 @@ sub send_req {
     # assemble request
     my $url = $site->MREST_CLI_URI_BASE;
     $url .= uri_escape( $path, '%' );
-    print "Encoded URI is $url\n";
+    #print "Encoded URI is $url\n";
     my $r = $methods{$method}->( 
         $url,
         Accept => 'application/json',
@@ -208,6 +208,8 @@ sub send_req {
     } else {
         $status = $CELL->status_warn( 'MREST_CLI_HTTP_REQUEST_OK_NODATA' );
     }
+    $status->{'http_code'} = $response->code;
+    $status->{'http_message'} = $response->message;
     $status->{'http_status'} = $response->code . ' ' . $response->message;
 
     # load up headers
