@@ -72,11 +72,11 @@ App::MREST::Resource - HTTP request/response cycle
 
 =head1 VERSION
 
-Version 0.256
+Version 0.261
 
 =cut
 
-our $VERSION = '0.256';
+our $VERSION = '0.261';
 
 
 
@@ -163,15 +163,18 @@ sub push_onto_context {
 
 Although L<Web::Machine> takes care of setting the HTTP response status code,
 but when we have to override L<Web::Machine>'s value we have this "MREST
-declared status" mechanism, which places a C<declared_status> in the context.
-During finalization, the code placed in this property clobbers whatever
-code L<Web::Machine> came up with.
+declared status" mechanism, which places a C<declared_status> property in
+the context. During finalization, the HTTP status code placed in this
+property overrides the one L<Web::Machine> came up with.
 
 
 =head3 mrest_declare_status
 
-This method takes either a ready-made App::CELL::Status object or,
-alternatively, a PARAMHASH with the following keys, all of which are optional:
+This method takes either a ready-made L<App::CELL::Status> object or,
+alternatively, a PARAMHASH. In the former case, an HTTP status code can be
+"forced" on the response by including a C<http_code> property in the
+object. In the latter case, the following keys are recognized (and all of
+them are optional):
 
 =over
 
@@ -204,20 +207,44 @@ sub mrest_declare_status {
 
     # if status gets declared multiple times, keep only the first one
     if ( exists $self->context->{'declared_status'} ) {
-        $log->notice( "Cowardly refusing to overwrite previously declared status with this one: " . Dumper( \@ARGS ) );
+        $log->notice( 
+            "Cowardly refusing to overwrite previously declared status with this one: " . 
+            Dumper( \@ARGS ) 
+        );
         return;
     }
 
     my $declared_status;
+
     if ( @ARGS and ref( $ARGS[0] ) eq 'App::CELL::Status' ) {
+
+        #
+        # App::CELL::Status object was given; bend it to our needs
+        #
         $declared_status = $ARGS[0];
-        if ( ! $declared_status->payload->{'uri_path'} ) {
-            $declared_status->payload->{'uri_path'} = $self->context->{'uri_path'};
+
+        # make sure there is a payload and it is a hashref
+        if ( ! $declared_status->payload ) {
+            $declared_status->payload( {} );
         }
-        if ( ! $declared_status->payload->{'resource_name'} ) {
-            $declared_status->payload->{'resource_name'} = $self->context->{'resource_name'};
+
+        # if 'http_code' property given, move it to the payload
+        if ( my $hc = delete( $declared_status->{'http_code'} ) ) {
+            $declared_status->payload->{'http_code'} = $hc;
         }
+
+        # handle 'permanent' property
+        if ( my $pt = delete( $declared_status->{'permanent'} ) ) {
+            $declared_status->payload->{'permanent'} = $pt ? JSON::true : JSON::false;
+        } else {
+            $declared_status->payload->{'permanent'} = JSON::true;
+        }
+
     } else {
+
+        #
+        # PARAMHASH was given
+        #
         my %ARGS = validate( @ARGS, {
             'level' => { type => SCALAR, default => 'ERR' },
             'code' => { type => SCALAR|UNDEF, default => undef },
@@ -232,21 +259,25 @@ sub mrest_declare_status {
             args => $ARGS{'args'},
             payload => {
                 http_code => $ARGS{'code'},  # might be undef
-                uri_path => $self->context->{'uri_path'},
-                resource_name => $self->context->{'resource_name'},
-                http_method => $self->context->{'method'},
-                found_in => {
-                    package => (caller)[0],
-                    file => (caller)[1],
-                    line => (caller)[2]+0,
-                },
                 permanent => ( $ARGS{'permanent'} )
                     ? JSON::true
                     : JSON::false,
             },
         );
+
     }
 
+    # add standard properties to the payload
+    $declared_status->payload->{'uri_path'} = $self->context->{'uri_path'};
+    $declared_status->payload->{'resource_name'} = $self->context->{'resource_name'};
+    $declared_status->payload->{'http_method'} = $self->context->{'method'};
+    $declared_status->payload->{'found_in'} = {
+        package => (caller)[0],
+        file => (caller)[1],
+        line => (caller)[2]+0,
+    };
+
+    # the object is "done": push it onto the context
     $self->push_onto_context( {
         'declared_status' => $declared_status,
     } );
@@ -255,19 +286,46 @@ sub mrest_declare_status {
 
 =head3 mrest_declared_status_code
 
-Accessor method, gets just the code.
+Accessor method, gets just the HTTP status code (might be undef);
+and allows setting the HTTP status code, as well, by providing an argument.
 
 =cut
 
 sub mrest_declared_status_code {
-    my $self = shift;
-    if ( $self->context->{'declared_status'} ) {
-        return $self->context->{'declared_status'}->payload->{'http_code'};
-    }
-    return;
+    my ( $self, $arg ) = @_;
+    return unless ref( $self->context->{'declared_status'} ) eq 'App::CELL::Status';
+
+    my $dsc = $self->context->{'declared_status'}->payload->{'http_code'};
+
+    if ( $arg ) {
+        $log->warn( "Overriding previous declared status code ->" .
+            ( $dsc || 'undefined' ) .
+            "<- with new value -> " .
+            ( $arg || 'undefined' ) .
+            "<->" );
+        $self->context->{'declared_status'}->payload->{'http_code'} = $arg;
+        $dsc = $arg;
+    } 
+
+    return $dsc;
 }
 
 
+=head3 mrest_declared_status_explanation
+
+Accessor method, gets just the explanation (might be undef).
+Does not allow changing the explanation - for this, nullify the 
+declared status and declare a new one.
+
+=cut
+
+sub mrest_declared_status_explanation {
+    my ( $self, $arg ) = @_;
+    return unless ref( $self->context->{'declared_status'} ) eq 'App::CELL::Status';
+
+    return $self->context->{'declared_status'}->text;
+}
+
 =head2 status_declared
 
 Boolean method - checks context for presence of 'declared_status' property. If 
@@ -289,6 +347,18 @@ sub status_declared {
 }
 
 
+=head2 declared_status
+
+Synonym for C<status_declared>
+
+=cut
+
+sub declared_status {
+    my $self = shift;
+    return $self->status_declared;
+}
+
+
 =head2 nullify_declared_status
 
 This method nullifies any declared status that might be pending.
@@ -688,7 +758,9 @@ sub known_content_type {
     my ( $self, $content_type ) = @_;
     $log->debug( "Entering " . __PACKAGE__ . "::known_content_type (B5)" ) unless $muffle{1};
 
-    # bend over backwards to determine content type
+    return 1 if not $content_type;
+
+    # if $content_type is a blessed object, deal with that
     my $ct_isa = ref( $content_type );
     if ( $ct_isa ) {
         $log->debug( "\$content_type is a ->$ct_isa<-" ) unless $muffle{1};
@@ -698,9 +770,8 @@ sub known_content_type {
             return 0;
         }
         $content_type = $content_type->type; # convert object to string
-    } else {
-        $content_type = $content_type || '';
     }
+
     $log->debug( "Content type of this request is ->$content_type<-" ) unless $muffle{1};
 
     # push it onto context
